@@ -235,10 +235,14 @@ class UBXMessage:
         """
         # pylint: disable=no-member
 
+        # if HP element of NAV-HPPOSLLH or NAV-HPPOSECEF message type
+        isNavHP = self._is_navhp(key)
+
         # if attribute is scaled
         scale = 1
         if isinstance(att, list) and self._scaling:
-            scale = att[1]
+            if not isNavHP:  # don't scale NavHP elements at this point
+                scale = att[1]
             att = att[0]
 
         # if attribute is part of a (nested) repeating group, suffix name with index
@@ -253,11 +257,6 @@ class UBXMessage:
         else:
             atts = attsiz(att)
 
-        # if HP element of NAV-HPPOSLLH or NAV-HPPOSECEF message type
-        isNavHP = self._is_navhp(key)
-        if isNavHP:
-            scale = 1
-
         # if payload keyword has been provided,
         # use the appropriate offset of the payload
         if "payload" in kwargs:
@@ -505,6 +504,8 @@ class UBXMessage:
                 pdict = self._get_rxmpmreq_version(**kwargs)
             elif self._ubxClass == b"\x0d" and self._ubxID == b"\x15":  # TIM-VCOCAL SET
                 pdict = self._get_timvcocal_version(**kwargs)
+            elif self._ubxClass == b"\x06" and self._ubxID == b"\x06":  # CFG-DAT SET
+                pdict = self._get_cfgdat_version(**kwargs)
             else:
                 pdict = ubs.UBX_PAYLOADS_SET[self.identity]
         else:  # GET message
@@ -742,6 +743,27 @@ class UBXMessage:
             pdict = ubs.UBX_PAYLOADS_SET["TIM-VCOCAL"]  # cal
         return pdict
 
+    def _get_cfgdat_version(self, **kwargs) -> dict:
+        """
+        Select appropriate CFG-DAT SET payload definition by checking
+        presence of datumNum keyword or payload length of 2 bytes.
+
+        :param kwargs: optional payload key/value pairs
+        :return: dictionary representing payload definition
+        :rtype: dict
+
+        """
+        # pylint: disable=no-self-use
+
+        lpd = 0
+        if "payload" in kwargs:
+            lpd = len(kwargs["payload"])
+        if lpd == 2 or "datumNum" in kwargs:
+            pdict = ubs.UBX_PAYLOADS_SET["CFG-DAT-NUM"]  # datum num set
+        else:
+            pdict = ubs.UBX_PAYLOADS_SET["CFG-DAT"]  # manual datum set
+        return pdict
+
     def _calc_num_repeats(
         self, attd: dict, payload: bytes, offset: int, offsetend: int = 0
     ) -> int:
