@@ -145,7 +145,7 @@ UBX_MSGIDS = {
     b"\x06\x13": "CFG-ANT",
     b"\x06\x93": "CFG-BATCH",
     b"\x06\x09": "CFG-CFG",
-    b"\x06\x06": "CFG-DAT",
+    b"\x06\x06": "CFG-DAT",  # two versions
     b"\x06\x70": "CFG-DGNSS",
     b"\x06\x61": "CFG-DOSC",
     b"\x06\x85": "CFG-DYNSEED",
@@ -304,6 +304,7 @@ UBX_MSGIDS = {
     b"\x01\x28": "NAV-NMI",
     b"\x01\x09": "NAV-ODO",
     b"\x01\x34": "NAV-ORB",
+    b"\x01\x62": "NAV-PL",
     b"\x01\x01": "NAV-POSECEF",
     b"\x01\x02": "NAV-POSLLH",
     b"\x01\x17": "NAV-PVAT",
